==> pysmarlaapi-0.2.4.tar.gz: pysmarlaapi-0.2.4/tests/test.py <==
import asyncio
import logging
import sys
import threading
import time

sys.path.append("../")
logging.basicConfig(level=20)

from pysmarlaapi import Connection, Federwiege

try:
    from config import AUTH_TOKEN_PERSONAL, HOST
except ImportError:
    print("config.py or mandatory variables missing, please add in root folder...")
    exit()

loop = asyncio.get_event_loop()
async_thread = threading.Thread(target=loop.run_forever)

connection = Connection(url=HOST, token_json=AUTH_TOKEN_PERSONAL)

federwiege = Federwiege(loop, connection)


def main():
    async_thread.start()
    federwiege.register()
    federwiege.connect()

    while not (federwiege.connected and federwiege.available):
        time.sleep(1)

    swing_active_prop = federwiege.get_service("babywiege").get_property("swing_active")
    intensity_prop = federwiege.get_service("babywiege").get_property("intensity")
    oscillation_prop = federwiege.get_service("analyser").get_property("oscillation")

    time.sleep(1)

    value = swing_active_prop.get()
    print(f"Swing Active: {value}")
    intensity = intensity_prop.get()
    print(f"Intensity: {intensity}%")
    oscillation = oscillation_prop.get()
    print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")

    swing_active_prop.set(True)
    intensity_prop.set(60)

    time.sleep(1)

    value = swing_active_prop.get()
    print(f"Swing Active: {value}")
    intensity = intensity_prop.get()
    print(f"Intensity: {intensity}%")
    oscillation = oscillation_prop.get()
    print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")

    time.sleep(1)

    while True:
        value = swing_active_prop.get()
        print(f"Swing Active: {value}")
        intensity = intensity_prop.get()
        print(f"Intensity: {intensity}%")
        oscillation = oscillation_prop.get()
        print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")
        time.sleep(1)


if __name__ == "__main__":
    try:
        main()
    except BaseException:
        pass
    federwiege.disconnect()
    while federwiege.connected:
        time.sleep(1)
    loop.call_soon_threadsafe(loop.stop)

==> pysmarlaapi-0.3.0.tar.gz: pysmarlaapi-0.3.0/tests/test.py <==
import asyncio
import logging
import sys
import threading
import time

sys.path.append("../")
logging.basicConfig(level=20)

from pysmarlaapi import Connection, Federwiege

try:
    from config import AUTH_TOKEN_B64, HOST
except ImportError:
    print("config.py or mandatory variables missing, please add in root folder...")
    sys.exit()

loop = asyncio.get_event_loop()
async_thread = threading.Thread(target=loop.run_forever)

connection = Connection(url=HOST, token_b64=AUTH_TOKEN_B64)

federwiege = Federwiege(loop, connection)


def main():
    async_thread.start()
    federwiege.register()
    federwiege.connect()

    while not (federwiege.connected and federwiege.available):
        time.sleep(1)

    swing_active_prop = federwiege.get_service("babywiege").get_property("swing_active")
    intensity_prop = federwiege.get_service("babywiege").get_property("intensity")
    oscillation_prop = federwiege.get_service("analyser").get_property("oscillation")

    time.sleep(1)

    value = swing_active_prop.get()
    print(f"Swing Active: {value}")
    intensity = intensity_prop.get()
    print(f"Intensity: {intensity}%")
    oscillation = oscillation_prop.get()
    print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")

    swing_active_prop.set(True)
    intensity_prop.set(60)

    time.sleep(1)

    value = swing_active_prop.get()
    print(f"Swing Active: {value}")
    intensity = intensity_prop.get()
    print(f"Intensity: {intensity}%")
    oscillation = oscillation_prop.get()
    print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")

    time.sleep(1)

    while True:
        value = swing_active_prop.get()
        print(f"Swing Active: {value}")
        intensity = intensity_prop.get()
        print(f"Intensity: {intensity}%")
        oscillation = oscillation_prop.get()
        print(f"Amplitude: {oscillation[0]}mm Period: {oscillation[1]}ms")
        time.sleep(1)


if __name__ == "__main__":
    try:
        main()
    except BaseException:
        pass
    federwiege.disconnect()
    while federwiege.connected:
        time.sleep(1)
    loop.call_soon_threadsafe(loop.stop)
